==> gottet_1.1.9.orig.tar.gz: gottet-1.1.9/translations/gottet_zh.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh">
<context>
    <name>Board</name>
    <message>
        <source>Question</source>
        <translation>问题</translation>
    </message>
    <message>
        <source>End the current game?</source>
        <translation>结束当前游戏？</translation>
    </message>
    <message>
        <source>&lt;big&gt;&lt;b&gt;Paused&lt;/b&gt;&lt;/big&gt;&lt;br&gt;Click to resume playing.</source>
        <translation>&lt;big&gt;&lt;b&gt;已暂停&lt;/b&gt;&lt;/big&gt;&lt;br&gt;点击以恢复游戏。</translation>
    </message>
    <message>
        <source>&lt;big&gt;&lt;b&gt;Game Over!&lt;/b&gt;&lt;/big&gt;&lt;br&gt;Click to start a new game.</source>
        <translation>&lt;big&gt;&lt;b&gt;游戏结束！&lt;/b&gt;&lt;/big&gt;&lt;br&gt;点击以开始新游戏。</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>选择本游戏的语言:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;系统语言&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>提示</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>请重启本程序使语言设置生效。</translation>
    </message>
</context>
<context>
    <name>ScoreBoard</name>
    <message>
        <source>Gottet Scores</source>
        <translation>Gottet 分数</translation>
    </message>
    <message>
        <source>Level</source>
        <translation>等级</translation>
    </message>
    <message>
        <source>Lines</source>
        <translation>行数</translation>
    </message>
    <message>
        <source>Score</source>
        <translation>分数</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>好</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Gottet</source>
        <translation>Gottet</translation>
    </message>
    <message>
        <source>Click to start a new game.</source>
        <translation>点击以开始新游戏</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;游戏</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;新游戏</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;暂停</translation>
    </message>
    <message>
        <source>P</source>
        <translation>P</translation>
    </message>
    <message>
        <source>&amp;Resume</source>
        <translation>&amp;恢复</translation>
    </message>
    <message>
        <source>&amp;Scores</source>
        <translation>&amp;分数</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;退出程序</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;设置</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>程序 &amp;语言...</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;帮助</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;关于</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>关于 &amp;Qt</translation>
    </message>
    <message>
        <source>Next Piece</source>
        <translation>下一个方块</translation>
    </message>
    <message>
        <source>Level</source>
        <translation>等级</translation>
    </message>
    <message>
        <source>Removed Lines</source>
        <translation>消除行数</translation>
    </message>
    <message>
        <source>Score</source>
        <translation>分数</translation>
    </message>
    <message>
        <source>About</source>
        <translation>关于</translation>
    </message>
    <message>
        <source>A tetris clone I made for my wife</source>
        <translation>我为我妻子打造的俄罗斯方块克隆</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott.</source>
        <translation>版权所有 &amp;copy; 2008-%1 Graeme Gott.</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>基于 &lt;a href=%1&gt;GPL 3&lt;/a&gt; 协议发布</translation>
    </message>
</context>
</TS>

==> gottet_1.2.4.orig.tar.gz: gottet-1.2.4/translations/gottet_zh.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh">
<context>
    <name>Board</name>
    <message>
        <source>Question</source>
        <translation>问题</translation>
    </message>
    <message>
        <source>End the current game?</source>
        <translation>结束当前游戏？</translation>
    </message>
    <message>
        <source>&lt;big&gt;&lt;b&gt;Paused&lt;/b&gt;&lt;/big&gt;&lt;br&gt;Click to resume playing.</source>
        <translation>&lt;big&gt;&lt;b&gt;已暂停&lt;/b&gt;&lt;/big&gt;&lt;br&gt;点击以恢复游戏。</translation>
    </message>
    <message>
        <source>&lt;big&gt;&lt;b&gt;Game Over!&lt;/b&gt;&lt;/big&gt;&lt;br&gt;Click to start a new game.</source>
        <translation>&lt;big&gt;&lt;b&gt;游戏结束！&lt;/b&gt;&lt;/big&gt;&lt;br&gt;点击以开始新游戏。</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>选择本游戏的语言:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;系统语言&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>提示</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>请重启本程序使语言设置生效。</translation>
    </message>
</context>
<context>
    <name>ScoresDialog</name>
    <message>
        <source>Level</source>
        <translation>等级</translation>
    </message>
    <message>
        <source>Lines</source>
        <translation>行数</translation>
    </message>
    <message>
        <source>Score</source>
        <translation>分数</translation>
    </message>
    <message>
        <source>High Scores</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rank</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>#%1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Congratulations!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You beat your top score!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Well done!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You have a new high score!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Gottet</source>
        <translation>Gottet</translation>
    </message>
    <message>
        <source>Click to start a new game.</source>
        <translation>点击以开始新游戏</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;游戏</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;新游戏</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;暂停</translation>
    </message>
    <message>
        <source>P</source>
        <translation>P</translation>
    </message>
    <message>
        <source>&amp;Scores</source>
        <translation>&amp;分数</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;退出程序</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;设置</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>程序 &amp;语言...</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;帮助</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;关于</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>关于 &amp;Qt</translation>
    </message>
    <message>
        <source>Next Piece</source>
        <translation>下一个方块</translation>
    </message>
    <message>
        <source>Level</source>
        <translation>等级</translation>
    </message>
    <message>
        <source>Removed Lines</source>
        <translation>消除行数</translation>
    </message>
    <message>
        <source>Score</source>
        <translation>分数</translation>
    </message>
    <message>
        <source>About</source>
        <translation>关于</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott.</source>
        <translation>版权所有 &amp;copy; 2008-%1 Graeme Gott.</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>基于 &lt;a href=%1&gt;GPL 3&lt;/a&gt; 协议发布</translation>
    </message>
    <message>
        <source>Ctrl+H</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>A simple falling blocks game</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
